@@ -57,8 +57,6 @@ class DataBarsRenderer:
 
 class DecimalStringFormat:
     type = "decimal"
-    minDecimals = 4
-    maxDecimals = 4
 
     def __init__(self, min=4, max=4):
         self.minDecimals = min
@@ -68,10 +66,18 @@ class DecimalStringFormat:
 class ImageFormat:
     type = "image"
 
+    def __init__(self, **kwargs):
+        if 'width' in kwargs:
+            self.width = kwargs.get('width')
+
 
 class HTMLFormat:
     type = "html"
 
+    def __init__(self, **kwargs):
+        if 'width' in kwargs:
+            self.width = kwargs.get('width')
+
 
 class HighlightStyle(Enum):
     FULL_ROW = 1
@@ -80,6 +86,7 @@ class HighlightStyle(Enum):
 
 class HeatmapHighlighter:
     type = "HeatmapHighlighter"
+
     def __init__(self, colName, style, minVal, maxVal, minColor, maxColor):
         self.colName = colName
         self.style = style.name
@@ -102,12 +109,12 @@ class TableDisplayStringFormat:
         return DecimalStringFormat(min, max)
 
     @staticmethod
-    def getHTMLFormat():
-        return HTMLFormat()
+    def getHTMLFormat(**kwargs):
+        return HTMLFormat(**kwargs)
 
     @staticmethod
-    def getImageFormat():
-        return ImageFormat()
+    def getImageFormat(**kwargs):
+        return ImageFormat(**kwargs)
 
 class TableDisplayCellHighlighter:
     FULL_ROW = HighlightStyle.FULL_ROW
